package ca.uhn.hl7v2.model.v25.segment;

import ca.uhn.hl7v2.model.*;
import ca.uhn.hl7v2.model.v25.datatype.*;
import ca.uhn.log.HapiLogFactory;
import ca.uhn.hl7v2.parser.ModelClassFactory;
import ca.uhn.hl7v2.HL7Exception;

/**
 * <p>Represents an HL7 CDM message segment. 
 * This segment has the following fields:</p><p>
 * CDM-1: Primary Key Value - CDM (CE)<br> 
 * CDM-2: Charge Code Alias (CE)<br> 
 * CDM-3: Charge Description Short (ST)<br> 
 * CDM-4: Charge Description Long (ST)<br> 
 * CDM-5: Description Override Indicator (IS)<br> 
 * CDM-6: Exploding Charges (CE)<br> 
 * CDM-7: Procedure Code (CE)<br> 
 * CDM-8: Active/Inactive Flag (ID)<br> 
 * CDM-9: Inventory Number (CE)<br> 
 * CDM-10: Resource Load (NM)<br> 
 * CDM-11: Contract Number (CX)<br> 
 * CDM-12: Contract Organization (XON)<br> 
 * CDM-13: Room Fee Indicator (ID)<br> 
 * </p><p>The get...() methods return data from individual fields.  These methods 
 * do not throw exceptions and may therefore have to handle exceptions internally.  
 * If an exception is handled internally, it is logged and null is returned.  
 * This is not expected to happen - if it does happen this indicates not so much 
 * an exceptional circumstance as a bug in the code for this class.</p>    
 */
public class CDM extends AbstractSegment  {

  /**
   * Creates a CDM (Charge Description Master) segment object that belongs to the given 
   * message.  
   */
  public CDM(Group parent, ModelClassFactory factory) {
    super(parent, factory);
    Message message = getMessage();
    try {
       this.add(CE.class, true, 1, 250, new Object[]{message}, "Primary Key Value - CDM");
       this.add(CE.class, false, 0, 250, new Object[]{message}, "Charge Code Alias");
       this.add(ST.class, true, 1, 20, new Object[]{message}, "Charge Description Short");
       this.add(ST.class, false, 1, 250, new Object[]{message}, "Charge Description Long");
       this.add(IS.class, false, 1, 1, new Object[]{message, new Integer(268)}, "Description Override Indicator");
       this.add(CE.class, false, 0, 250, new Object[]{message}, "Exploding Charges");
       this.add(CE.class, false, 0, 250, new Object[]{message}, "Procedure Code");
       this.add(ID.class, false, 1, 1, new Object[]{message, new Integer(183)}, "Active/Inactive Flag");
       this.add(CE.class, false, 0, 250, new Object[]{message}, "Inventory Number");
       this.add(NM.class, false, 1, 12, new Object[]{message}, "Resource Load");
       this.add(CX.class, false, 0, 250, new Object[]{message}, "Contract Number");
       this.add(XON.class, false, 0, 250, new Object[]{message}, "Contract Organization");
       this.add(ID.class, false, 1, 1, new Object[]{message, new Integer(136)}, "Room Fee Indicator");
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Can't instantiate " + this.getClass().getName(), he);
    }
  }

  /**
   * Returns Primary Key Value - CDM (CDM-1).
   */
  public CE getPrimaryKeyValueCDM()  {
    CE ret = null;
    try {
        Type t = this.getField(1, 0);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Primary Key Value - CDM (CDM-1).
   */
  public CE getCdm1_PrimaryKeyValueCDM()  {
    CE ret = null;
    try {
        Type t = this.getField(1, 0);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a single repetition of Charge Code Alias (CDM-2).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getChargeCodeAlias(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(2, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Charge Code Alias (CDM-2).
   */
  public CE[] getChargeCodeAlias() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(2);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Charge Code Alias (CDM-2).
   */
  public int getChargeCodeAliasReps() {
    try {
        return this.getField(2).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Charge Code Alias (CDM-2) at a given index and returns it.
   * @param index The index
   */
  public CE insertChargeCodeAlias(int index) throws HL7Exception {
     return (CE) super.insertRepetition(2, index);
  }

  /**
   * Removes a repetition of Charge Code Alias (CDM-2) at a given index and returns it.
   * @param index The index
   */
  public CE removeChargeCodeAlias(int index) throws HL7Exception {
     return (CE) super.removeRepetition(2, index);
  }

  /**
   * Returns a single repetition of Charge Code Alias (CDM-2).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getCdm2_ChargeCodeAlias(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(2, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Charge Code Alias (CDM-2).
   */
  public CE[] getCdm2_ChargeCodeAlias() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(2);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Charge Code Alias (CDM-2).
   */
  public int getCdm2_ChargeCodeAliasReps() {
    try {
        return this.getField(2).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Charge Code Alias (CDM-2) at a given index and returns it.
   * @param index The index
   */
  public CE insertCdm2_ChargeCodeAlias(int index) throws HL7Exception {
     return (CE) super.insertRepetition(2, index);
  }

  /**
   * Removes a repetition of Charge Code Alias (CDM-2) at a given index and returns it.
   * @param index The index
   */
  public CE removeCdm2_ChargeCodeAlias(int index) throws HL7Exception {
     return (CE) super.removeRepetition(2, index);
  }

  /**
   * Returns Charge Description Short (CDM-3).
   */
  public ST getChargeDescriptionShort()  {
    ST ret = null;
    try {
        Type t = this.getField(3, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Charge Description Short (CDM-3).
   */
  public ST getCdm3_ChargeDescriptionShort()  {
    ST ret = null;
    try {
        Type t = this.getField(3, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Charge Description Long (CDM-4).
   */
  public ST getChargeDescriptionLong()  {
    ST ret = null;
    try {
        Type t = this.getField(4, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Charge Description Long (CDM-4).
   */
  public ST getCdm4_ChargeDescriptionLong()  {
    ST ret = null;
    try {
        Type t = this.getField(4, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Description Override Indicator (CDM-5).
   */
  public IS getDescriptionOverrideIndicator()  {
    IS ret = null;
    try {
        Type t = this.getField(5, 0);
        ret = (IS)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Description Override Indicator (CDM-5).
   */
  public IS getCdm5_DescriptionOverrideIndicator()  {
    IS ret = null;
    try {
        Type t = this.getField(5, 0);
        ret = (IS)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a single repetition of Exploding Charges (CDM-6).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getExplodingCharges(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(6, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Exploding Charges (CDM-6).
   */
  public CE[] getExplodingCharges() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(6);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Exploding Charges (CDM-6).
   */
  public int getExplodingChargesReps() {
    try {
        return this.getField(6).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Exploding Charges (CDM-6) at a given index and returns it.
   * @param index The index
   */
  public CE insertExplodingCharges(int index) throws HL7Exception {
     return (CE) super.insertRepetition(6, index);
  }

  /**
   * Removes a repetition of Exploding Charges (CDM-6) at a given index and returns it.
   * @param index The index
   */
  public CE removeExplodingCharges(int index) throws HL7Exception {
     return (CE) super.removeRepetition(6, index);
  }

  /**
   * Returns a single repetition of Exploding Charges (CDM-6).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getCdm6_ExplodingCharges(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(6, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Exploding Charges (CDM-6).
   */
  public CE[] getCdm6_ExplodingCharges() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(6);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Exploding Charges (CDM-6).
   */
  public int getCdm6_ExplodingChargesReps() {
    try {
        return this.getField(6).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Exploding Charges (CDM-6) at a given index and returns it.
   * @param index The index
   */
  public CE insertCdm6_ExplodingCharges(int index) throws HL7Exception {
     return (CE) super.insertRepetition(6, index);
  }

  /**
   * Removes a repetition of Exploding Charges (CDM-6) at a given index and returns it.
   * @param index The index
   */
  public CE removeCdm6_ExplodingCharges(int index) throws HL7Exception {
     return (CE) super.removeRepetition(6, index);
  }

  /**
   * Returns a single repetition of Procedure Code (CDM-7).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getProcedureCode(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(7, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Procedure Code (CDM-7).
   */
  public CE[] getProcedureCode() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(7);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Procedure Code (CDM-7).
   */
  public int getProcedureCodeReps() {
    try {
        return this.getField(7).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Procedure Code (CDM-7) at a given index and returns it.
   * @param index The index
   */
  public CE insertProcedureCode(int index) throws HL7Exception {
     return (CE) super.insertRepetition(7, index);
  }

  /**
   * Removes a repetition of Procedure Code (CDM-7) at a given index and returns it.
   * @param index The index
   */
  public CE removeProcedureCode(int index) throws HL7Exception {
     return (CE) super.removeRepetition(7, index);
  }

  /**
   * Returns a single repetition of Procedure Code (CDM-7).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getCdm7_ProcedureCode(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(7, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Procedure Code (CDM-7).
   */
  public CE[] getCdm7_ProcedureCode() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(7);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Procedure Code (CDM-7).
   */
  public int getCdm7_ProcedureCodeReps() {
    try {
        return this.getField(7).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Procedure Code (CDM-7) at a given index and returns it.
   * @param index The index
   */
  public CE insertCdm7_ProcedureCode(int index) throws HL7Exception {
     return (CE) super.insertRepetition(7, index);
  }

  /**
   * Removes a repetition of Procedure Code (CDM-7) at a given index and returns it.
   * @param index The index
   */
  public CE removeCdm7_ProcedureCode(int index) throws HL7Exception {
     return (CE) super.removeRepetition(7, index);
  }

  /**
   * Returns Active/Inactive Flag (CDM-8).
   */
  public ID getActiveInactiveFlag()  {
    ID ret = null;
    try {
        Type t = this.getField(8, 0);
        ret = (ID)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Active/Inactive Flag (CDM-8).
   */
  public ID getCdm8_ActiveInactiveFlag()  {
    ID ret = null;
    try {
        Type t = this.getField(8, 0);
        ret = (ID)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a single repetition of Inventory Number (CDM-9).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getInventoryNumber(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(9, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Inventory Number (CDM-9).
   */
  public CE[] getInventoryNumber() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(9);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Inventory Number (CDM-9).
   */
  public int getInventoryNumberReps() {
    try {
        return this.getField(9).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Inventory Number (CDM-9) at a given index and returns it.
   * @param index The index
   */
  public CE insertInventoryNumber(int index) throws HL7Exception {
     return (CE) super.insertRepetition(9, index);
  }

  /**
   * Removes a repetition of Inventory Number (CDM-9) at a given index and returns it.
   * @param index The index
   */
  public CE removeInventoryNumber(int index) throws HL7Exception {
     return (CE) super.removeRepetition(9, index);
  }

  /**
   * Returns a single repetition of Inventory Number (CDM-9).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getCdm9_InventoryNumber(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(9, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Inventory Number (CDM-9).
   */
  public CE[] getCdm9_InventoryNumber() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(9);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Inventory Number (CDM-9).
   */
  public int getCdm9_InventoryNumberReps() {
    try {
        return this.getField(9).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Inventory Number (CDM-9) at a given index and returns it.
   * @param index The index
   */
  public CE insertCdm9_InventoryNumber(int index) throws HL7Exception {
     return (CE) super.insertRepetition(9, index);
  }

  /**
   * Removes a repetition of Inventory Number (CDM-9) at a given index and returns it.
   * @param index The index
   */
  public CE removeCdm9_InventoryNumber(int index) throws HL7Exception {
     return (CE) super.removeRepetition(9, index);
  }

  /**
   * Returns Resource Load (CDM-10).
   */
  public NM getResourceLoad()  {
    NM ret = null;
    try {
        Type t = this.getField(10, 0);
        ret = (NM)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Resource Load (CDM-10).
   */
  public NM getCdm10_ResourceLoad()  {
    NM ret = null;
    try {
        Type t = this.getField(10, 0);
        ret = (NM)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a single repetition of Contract Number (CDM-11).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CX getContractNumber(int rep) throws HL7Exception {
    CX ret = null;
    try {
        Type t = this.getField(11, rep);
        ret = (CX)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Contract Number (CDM-11).
   */
  public CX[] getContractNumber() {
     CX[] ret = null;
    try {
        Type[] t = this.getField(11);  
        ret = new CX[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CX)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Contract Number (CDM-11).
   */
  public int getContractNumberReps() {
    try {
        return this.getField(11).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Contract Number (CDM-11) at a given index and returns it.
   * @param index The index
   */
  public CX insertContractNumber(int index) throws HL7Exception {
     return (CX) super.insertRepetition(11, index);
  }

  /**
   * Removes a repetition of Contract Number (CDM-11) at a given index and returns it.
   * @param index The index
   */
  public CX removeContractNumber(int index) throws HL7Exception {
     return (CX) super.removeRepetition(11, index);
  }

  /**
   * Returns a single repetition of Contract Number (CDM-11).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CX getCdm11_ContractNumber(int rep) throws HL7Exception {
    CX ret = null;
    try {
        Type t = this.getField(11, rep);
        ret = (CX)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Contract Number (CDM-11).
   */
  public CX[] getCdm11_ContractNumber() {
     CX[] ret = null;
    try {
        Type[] t = this.getField(11);  
        ret = new CX[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CX)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Contract Number (CDM-11).
   */
  public int getCdm11_ContractNumberReps() {
    try {
        return this.getField(11).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Contract Number (CDM-11) at a given index and returns it.
   * @param index The index
   */
  public CX insertCdm11_ContractNumber(int index) throws HL7Exception {
     return (CX) super.insertRepetition(11, index);
  }

  /**
   * Removes a repetition of Contract Number (CDM-11) at a given index and returns it.
   * @param index The index
   */
  public CX removeCdm11_ContractNumber(int index) throws HL7Exception {
     return (CX) super.removeRepetition(11, index);
  }

  /**
   * Returns a single repetition of Contract Organization (CDM-12).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public XON getContractOrganization(int rep) throws HL7Exception {
    XON ret = null;
    try {
        Type t = this.getField(12, rep);
        ret = (XON)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Contract Organization (CDM-12).
   */
  public XON[] getContractOrganization() {
     XON[] ret = null;
    try {
        Type[] t = this.getField(12);  
        ret = new XON[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (XON)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Contract Organization (CDM-12).
   */
  public int getContractOrganizationReps() {
    try {
        return this.getField(12).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Contract Organization (CDM-12) at a given index and returns it.
   * @param index The index
   */
  public XON insertContractOrganization(int index) throws HL7Exception {
     return (XON) super.insertRepetition(12, index);
  }

  /**
   * Removes a repetition of Contract Organization (CDM-12) at a given index and returns it.
   * @param index The index
   */
  public XON removeContractOrganization(int index) throws HL7Exception {
     return (XON) super.removeRepetition(12, index);
  }

  /**
   * Returns a single repetition of Contract Organization (CDM-12).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public XON getCdm12_ContractOrganization(int rep) throws HL7Exception {
    XON ret = null;
    try {
        Type t = this.getField(12, rep);
        ret = (XON)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Contract Organization (CDM-12).
   */
  public XON[] getCdm12_ContractOrganization() {
     XON[] ret = null;
    try {
        Type[] t = this.getField(12);  
        ret = new XON[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (XON)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Contract Organization (CDM-12).
   */
  public int getCdm12_ContractOrganizationReps() {
    try {
        return this.getField(12).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Contract Organization (CDM-12) at a given index and returns it.
   * @param index The index
   */
  public XON insertCdm12_ContractOrganization(int index) throws HL7Exception {
     return (XON) super.insertRepetition(12, index);
  }

  /**
   * Removes a repetition of Contract Organization (CDM-12) at a given index and returns it.
   * @param index The index
   */
  public XON removeCdm12_ContractOrganization(int index) throws HL7Exception {
     return (XON) super.removeRepetition(12, index);
  }

  /**
   * Returns Room Fee Indicator (CDM-13).
   */
  public ID getRoomFeeIndicator()  {
    ID ret = null;
    try {
        Type t = this.getField(13, 0);
        ret = (ID)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Room Fee Indicator (CDM-13).
   */
  public ID getCdm13_RoomFeeIndicator()  {
    ID ret = null;
    try {
        Type t = this.getField(13, 0);
        ret = (ID)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

   protected Type createNewTypeWithoutReflection(int field) {
      switch (field) {
         case 0: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 1: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 2: return new ca.uhn.hl7v2.model.v25.datatype.ST(getMessage());
         case 3: return new ca.uhn.hl7v2.model.v25.datatype.ST(getMessage());
         case 4: return new ca.uhn.hl7v2.model.v25.datatype.IS(getMessage(), new Integer(268));
         case 5: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 6: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 7: return new ca.uhn.hl7v2.model.v25.datatype.ID(getMessage(), new Integer(183));
         case 8: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 9: return new ca.uhn.hl7v2.model.v25.datatype.NM(getMessage());
         case 10: return new ca.uhn.hl7v2.model.v25.datatype.CX(getMessage());
         case 11: return new ca.uhn.hl7v2.model.v25.datatype.XON(getMessage());
         case 12: return new ca.uhn.hl7v2.model.v25.datatype.ID(getMessage(), new Integer(136));
         default: return null;
      }
   }

}