package ca.uhn.hl7v2.model.v25.segment;

import ca.uhn.hl7v2.model.*;
import ca.uhn.hl7v2.model.v25.datatype.*;
import ca.uhn.log.HapiLogFactory;
import ca.uhn.hl7v2.parser.ModelClassFactory;
import ca.uhn.hl7v2.HL7Exception;

/**
 * <p>Represents an HL7 ERQ message segment. 
 * This segment has the following fields:</p><p>
 * ERQ-1: Query Tag (ST)<br> 
 * ERQ-2: Event Identifier (CE)<br> 
 * ERQ-3: Input Parameter List (QIP)<br> 
 * </p><p>The get...() methods return data from individual fields.  These methods 
 * do not throw exceptions and may therefore have to handle exceptions internally.  
 * If an exception is handled internally, it is logged and null is returned.  
 * This is not expected to happen - if it does happen this indicates not so much 
 * an exceptional circumstance as a bug in the code for this class.</p>    
 */
public class ERQ extends AbstractSegment  {

  /**
   * Creates a ERQ (Event replay query) segment object that belongs to the given 
   * message.  
   */
  public ERQ(Group parent, ModelClassFactory factory) {
    super(parent, factory);
    Message message = getMessage();
    try {
       this.add(ST.class, false, 1, 32, new Object[]{message}, "Query Tag");
       this.add(CE.class, true, 1, 250, new Object[]{message}, "Event Identifier");
       this.add(QIP.class, false, 0, 256, new Object[]{message}, "Input Parameter List");
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Can't instantiate " + this.getClass().getName(), he);
    }
  }

  /**
   * Returns Query Tag (ERQ-1).
   */
  public ST getQueryTag()  {
    ST ret = null;
    try {
        Type t = this.getField(1, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Query Tag (ERQ-1).
   */
  public ST getErq1_QueryTag()  {
    ST ret = null;
    try {
        Type t = this.getField(1, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Event Identifier (ERQ-2).
   */
  public CE getEventIdentifier()  {
    CE ret = null;
    try {
        Type t = this.getField(2, 0);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Event Identifier (ERQ-2).
   */
  public CE getErq2_EventIdentifier()  {
    CE ret = null;
    try {
        Type t = this.getField(2, 0);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a single repetition of Input Parameter List (ERQ-3).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public QIP getInputParameterList(int rep) throws HL7Exception {
    QIP ret = null;
    try {
        Type t = this.getField(3, rep);
        ret = (QIP)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Input Parameter List (ERQ-3).
   */
  public QIP[] getInputParameterList() {
     QIP[] ret = null;
    try {
        Type[] t = this.getField(3);  
        ret = new QIP[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (QIP)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Input Parameter List (ERQ-3).
   */
  public int getInputParameterListReps() {
    try {
        return this.getField(3).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Input Parameter List (ERQ-3) at a given index and returns it.
   * @param index The index
   */
  public QIP insertInputParameterList(int index) throws HL7Exception {
     return (QIP) super.insertRepetition(3, index);
  }

  /**
   * Removes a repetition of Input Parameter List (ERQ-3) at a given index and returns it.
   * @param index The index
   */
  public QIP removeInputParameterList(int index) throws HL7Exception {
     return (QIP) super.removeRepetition(3, index);
  }

  /**
   * Returns a single repetition of Input Parameter List (ERQ-3).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public QIP getErq3_InputParameterList(int rep) throws HL7Exception {
    QIP ret = null;
    try {
        Type t = this.getField(3, rep);
        ret = (QIP)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Input Parameter List (ERQ-3).
   */
  public QIP[] getErq3_InputParameterList() {
     QIP[] ret = null;
    try {
        Type[] t = this.getField(3);  
        ret = new QIP[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (QIP)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Input Parameter List (ERQ-3).
   */
  public int getErq3_InputParameterListReps() {
    try {
        return this.getField(3).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Input Parameter List (ERQ-3) at a given index and returns it.
   * @param index The index
   */
  public QIP insertErq3_InputParameterList(int index) throws HL7Exception {
     return (QIP) super.insertRepetition(3, index);
  }

  /**
   * Removes a repetition of Input Parameter List (ERQ-3) at a given index and returns it.
   * @param index The index
   */
  public QIP removeErq3_InputParameterList(int index) throws HL7Exception {
     return (QIP) super.removeRepetition(3, index);
  }

   protected Type createNewTypeWithoutReflection(int field) {
      switch (field) {
         case 0: return new ca.uhn.hl7v2.model.v25.datatype.ST(getMessage());
         case 1: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 2: return new ca.uhn.hl7v2.model.v25.datatype.QIP(getMessage());
         default: return null;
      }
   }

}