package ca.uhn.hl7v2.model.v25.segment;

import ca.uhn.hl7v2.model.*;
import ca.uhn.hl7v2.model.v25.datatype.*;
import ca.uhn.log.HapiLogFactory;
import ca.uhn.hl7v2.parser.ModelClassFactory;
import ca.uhn.hl7v2.HL7Exception;

/**
 * <p>Represents an HL7 IPC message segment. 
 * This segment has the following fields:</p><p>
 * IPC-1: Accession Identifier (EI)<br> 
 * IPC-2: Requested Procedure ID (EI)<br> 
 * IPC-3: Study Instance UID (EI)<br> 
 * IPC-4: Scheduled Procedure Step ID (EI)<br> 
 * IPC-5: Modality (CE)<br> 
 * IPC-6: Protocol Code (CE)<br> 
 * IPC-7: Scheduled Station Name (EI)<br> 
 * IPC-8: Scheduled Procedure Step Location (CE)<br> 
 * IPC-9: Scheduled AE Title (ST)<br> 
 * </p><p>The get...() methods return data from individual fields.  These methods 
 * do not throw exceptions and may therefore have to handle exceptions internally.  
 * If an exception is handled internally, it is logged and null is returned.  
 * This is not expected to happen - if it does happen this indicates not so much 
 * an exceptional circumstance as a bug in the code for this class.</p>    
 */
public class IPC extends AbstractSegment  {

  /**
   * Creates a IPC (Imaging Procedure Control Segment) segment object that belongs to the given 
   * message.  
   */
  public IPC(Group parent, ModelClassFactory factory) {
    super(parent, factory);
    Message message = getMessage();
    try {
       this.add(EI.class, true, 1, 80, new Object[]{message}, "Accession Identifier");
       this.add(EI.class, true, 1, 22, new Object[]{message}, "Requested Procedure ID");
       this.add(EI.class, true, 1, 70, new Object[]{message}, "Study Instance UID");
       this.add(EI.class, true, 1, 22, new Object[]{message}, "Scheduled Procedure Step ID");
       this.add(CE.class, false, 1, 16, new Object[]{message}, "Modality");
       this.add(CE.class, false, 0, 250, new Object[]{message}, "Protocol Code");
       this.add(EI.class, false, 1, 22, new Object[]{message}, "Scheduled Station Name");
       this.add(CE.class, false, 0, 250, new Object[]{message}, "Scheduled Procedure Step Location");
       this.add(ST.class, false, 1, 16, new Object[]{message}, "Scheduled AE Title");
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Can't instantiate " + this.getClass().getName(), he);
    }
  }

  /**
   * Returns Accession Identifier (IPC-1).
   */
  public EI getAccessionIdentifier()  {
    EI ret = null;
    try {
        Type t = this.getField(1, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Accession Identifier (IPC-1).
   */
  public EI getIpc1_AccessionIdentifier()  {
    EI ret = null;
    try {
        Type t = this.getField(1, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Requested Procedure ID (IPC-2).
   */
  public EI getRequestedProcedureID()  {
    EI ret = null;
    try {
        Type t = this.getField(2, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Requested Procedure ID (IPC-2).
   */
  public EI getIpc2_RequestedProcedureID()  {
    EI ret = null;
    try {
        Type t = this.getField(2, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Study Instance UID (IPC-3).
   */
  public EI getStudyInstanceUID()  {
    EI ret = null;
    try {
        Type t = this.getField(3, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Study Instance UID (IPC-3).
   */
  public EI getIpc3_StudyInstanceUID()  {
    EI ret = null;
    try {
        Type t = this.getField(3, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Scheduled Procedure Step ID (IPC-4).
   */
  public EI getScheduledProcedureStepID()  {
    EI ret = null;
    try {
        Type t = this.getField(4, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Scheduled Procedure Step ID (IPC-4).
   */
  public EI getIpc4_ScheduledProcedureStepID()  {
    EI ret = null;
    try {
        Type t = this.getField(4, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Modality (IPC-5).
   */
  public CE getModality()  {
    CE ret = null;
    try {
        Type t = this.getField(5, 0);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Modality (IPC-5).
   */
  public CE getIpc5_Modality()  {
    CE ret = null;
    try {
        Type t = this.getField(5, 0);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a single repetition of Protocol Code (IPC-6).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getProtocolCode(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(6, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Protocol Code (IPC-6).
   */
  public CE[] getProtocolCode() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(6);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Protocol Code (IPC-6).
   */
  public int getProtocolCodeReps() {
    try {
        return this.getField(6).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Protocol Code (IPC-6) at a given index and returns it.
   * @param index The index
   */
  public CE insertProtocolCode(int index) throws HL7Exception {
     return (CE) super.insertRepetition(6, index);
  }

  /**
   * Removes a repetition of Protocol Code (IPC-6) at a given index and returns it.
   * @param index The index
   */
  public CE removeProtocolCode(int index) throws HL7Exception {
     return (CE) super.removeRepetition(6, index);
  }

  /**
   * Returns a single repetition of Protocol Code (IPC-6).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getIpc6_ProtocolCode(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(6, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Protocol Code (IPC-6).
   */
  public CE[] getIpc6_ProtocolCode() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(6);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Protocol Code (IPC-6).
   */
  public int getIpc6_ProtocolCodeReps() {
    try {
        return this.getField(6).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Protocol Code (IPC-6) at a given index and returns it.
   * @param index The index
   */
  public CE insertIpc6_ProtocolCode(int index) throws HL7Exception {
     return (CE) super.insertRepetition(6, index);
  }

  /**
   * Removes a repetition of Protocol Code (IPC-6) at a given index and returns it.
   * @param index The index
   */
  public CE removeIpc6_ProtocolCode(int index) throws HL7Exception {
     return (CE) super.removeRepetition(6, index);
  }

  /**
   * Returns Scheduled Station Name (IPC-7).
   */
  public EI getScheduledStationName()  {
    EI ret = null;
    try {
        Type t = this.getField(7, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Scheduled Station Name (IPC-7).
   */
  public EI getIpc7_ScheduledStationName()  {
    EI ret = null;
    try {
        Type t = this.getField(7, 0);
        ret = (EI)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a single repetition of Scheduled Procedure Step Location (IPC-8).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getScheduledProcedureStepLocation(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(8, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Scheduled Procedure Step Location (IPC-8).
   */
  public CE[] getScheduledProcedureStepLocation() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(8);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Scheduled Procedure Step Location (IPC-8).
   */
  public int getScheduledProcedureStepLocationReps() {
    try {
        return this.getField(8).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Scheduled Procedure Step Location (IPC-8) at a given index and returns it.
   * @param index The index
   */
  public CE insertScheduledProcedureStepLocation(int index) throws HL7Exception {
     return (CE) super.insertRepetition(8, index);
  }

  /**
   * Removes a repetition of Scheduled Procedure Step Location (IPC-8) at a given index and returns it.
   * @param index The index
   */
  public CE removeScheduledProcedureStepLocation(int index) throws HL7Exception {
     return (CE) super.removeRepetition(8, index);
  }

  /**
   * Returns a single repetition of Scheduled Procedure Step Location (IPC-8).
   * @param rep the repetition number (this is a repeating field)
   * @throws HL7Exception if the repetition number is invalid.
   */
  public CE getIpc8_ScheduledProcedureStepLocation(int rep) throws HL7Exception {
    CE ret = null;
    try {
        Type t = this.getField(8, rep);
        ret = (CE)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    }
    return ret;
  }

  /**
   * Returns all repetitions of Scheduled Procedure Step Location (IPC-8).
   */
  public CE[] getIpc8_ScheduledProcedureStepLocation() {
     CE[] ret = null;
    try {
        Type[] t = this.getField(8);  
        ret = new CE[t.length];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = (CE)t[i];
        }
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns a count of the number of repetitions of Scheduled Procedure Step Location (IPC-8).
   */
  public int getIpc8_ScheduledProcedureStepLocationReps() {
    try {
        return this.getField(8).length;  
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
  }

  /**
   * Inserts a repetition of Scheduled Procedure Step Location (IPC-8) at a given index and returns it.
   * @param index The index
   */
  public CE insertIpc8_ScheduledProcedureStepLocation(int index) throws HL7Exception {
     return (CE) super.insertRepetition(8, index);
  }

  /**
   * Removes a repetition of Scheduled Procedure Step Location (IPC-8) at a given index and returns it.
   * @param index The index
   */
  public CE removeIpc8_ScheduledProcedureStepLocation(int index) throws HL7Exception {
     return (CE) super.removeRepetition(8, index);
  }

  /**
   * Returns Scheduled AE Title (IPC-9).
   */
  public ST getScheduledAETitle()  {
    ST ret = null;
    try {
        Type t = this.getField(9, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

  /**
   * Returns Scheduled AE Title (IPC-9).
   */
  public ST getIpc9_ScheduledAETitle()  {
    ST ret = null;
    try {
        Type t = this.getField(9, 0);
        ret = (ST)t;
    } catch (ClassCastException cce) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", cce);
        throw new RuntimeException(cce);
    } catch (HL7Exception he) {
        HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected problem obtaining field value.  This is a bug.", he);
        throw new RuntimeException(he);
    }
    return ret;
  }

   protected Type createNewTypeWithoutReflection(int field) {
      switch (field) {
         case 0: return new ca.uhn.hl7v2.model.v25.datatype.EI(getMessage());
         case 1: return new ca.uhn.hl7v2.model.v25.datatype.EI(getMessage());
         case 2: return new ca.uhn.hl7v2.model.v25.datatype.EI(getMessage());
         case 3: return new ca.uhn.hl7v2.model.v25.datatype.EI(getMessage());
         case 4: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 5: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 6: return new ca.uhn.hl7v2.model.v25.datatype.EI(getMessage());
         case 7: return new ca.uhn.hl7v2.model.v25.datatype.CE(getMessage());
         case 8: return new ca.uhn.hl7v2.model.v25.datatype.ST(getMessage());
         default: return null;
      }
   }

}